|logo|

.. |logo| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/pymedphys_title.png
    :target: https://docs.pymedphys.com/

.. START_OF_DOCS_IMPORT

**A community effort to develop an open standard library for Medical Physics
in Python. Building quality transparent software together via peer review
and open source distribution. Open code is better science.**

|build| |pypi| |python| |license|

.. |build| image:: https://img.shields.io/endpoint.svg?url=https%3A%2F%2Factions-badge.atrox.dev%2Fpymedphys%2Fpymedphys%2Fbadge&label=build&logo=none
    :target: https://actions-badge.atrox.dev/pymedphys/pymedphys/goto

.. |pypi| image:: https://img.shields.io/pypi/v/pymedphys
    :target: https://pypi.org/project/pymedphys/

.. |python| image:: https://img.shields.io/pypi/pyversions/pymedphys
    :target: https://pypi.org/project/pymedphys/

.. |license| image:: https://img.shields.io/pypi/l/pymedphys
    :target: https://choosealicense.com/licenses/apache-2.0/


What is PyMedPhys?
------------------

A place to share, review, improve, and transparently learn off of each
other’s code. It is an open-source library of tools that we all have access
to. It is inspired by the collaborative work of our physics peers in astronomy
and their `Astropy Project`_. PyMedPhys is available on `PyPI`_ and `GitHub`_.

.. _`Astropy Project`: http://www.astropy.org/
.. _`PyPI`: https://pypi.org/project/pymedphys/
.. _`GitHub`: https://github.com/pymedphys/pymedphys


Table of contents
-----------------

`Tutorials`_
........................

Get started with a hands-on introduction to PyMedPhys for beginners

`How-To guides`_
........................

Guides and recipes for common problems and tasks

`Reference`_
............................

Technical reference for the `library`_ (modules, functions and classes),
as well as the available `command line tools`_.

`Background`_
..............................

Explanation and discussion of key topics and concepts


Beta level of development
-------------------------

PyMedPhys is currently within the ``beta`` stage of its life-cycle. It will
stay in this stage until the version number leaves ``0.x.x`` and enters
``1.x.x``. While PyMedPhys is in ``beta`` stage, **no API is guaranteed to be
stable from one release to the next.** In fact, it is very likely that the
entire API will change multiple times before a ``1.0.0`` release. In practice,
this means that upgrading ``pymedphys`` to a new version will possibly break
any code that was using the old version of pymedphys. We try to be abreast of
this by providing details of any breaking changes from one release to the next
within the `Release Notes`_.

Our Team
--------

PyMedPhys is what it is today due to its contributors.
Core contributors and contributors who have been active in the last six months
as well as their respective employers are presented below.

Core contributor(s)
...................

* `Simon Biggs`_
    * `Riverina Cancer Care Centre`_, Australia

.. _`Simon Biggs`: https://github.com/SimonBiggs


Active contributors
...................

* `Matthew Jennings`_
    * `Royal Adelaide Hospital`_, Australia

.. _`Matthew Jennings`: https://github.com/Matthew-Jennings

* `Jake Rembish`_
    * `UT Health San Antonio`_, USA

.. _`Jake Rembish`: https://github.com/rembishj

* `Phillip Chlap`_
    * `University of New South Wales`_, Australia
    * `South Western Sydney Local Health District`_, Australia

.. _`Phillip Chlap`: https://github.com/pchlap

* `Pedro Martinez`_
    * `University of Calgary`_, Canada
    * `Tom Baker Cancer Centre`_, Canada

.. _`Pedro Martinez`: https://github.com/peterg1t

* `Jacob McAloney`_
    * `Riverina Cancer Care Centre`_, Australia

.. _`Jacob McAloney`: https://github.com/JacobMcAloney

* `Matthew Cooper`_
    * University of Sydney, Australia

.. _`Matthew Cooper`: https://github.com/matthewdeancooper

* `Rafael Ayala`_
    * `Hospital General Universitario Gregorio Marañón`_, Spain

.. _`Rafael Ayala`: https://github.com/ayalalazaro


|rccc| |rah| |uth| |uoc| |hgugm|

Past contributors
.................

* `Matthew Sobolewski <https://github.com/msobolewski>`_
* `Paul King <https://github.com/kingrpaul>`_


.. |rccc| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/rccc_200x200.png
    :target: `Riverina Cancer Care Centre`_

.. |rah| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/gosa_200x200.png
    :target: `Royal Adelaide Hospital`_

.. |jarmc| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/jarmc_200x200.png
    :target: `Anderson Regional Cancer Center`_

.. |nbcc| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/nbcc_200x200.png
    :target: `Northern Beaches Cancer Care`_

.. |uoc| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/uoc_200x200.png
    :target: `University of Calgary`_

.. |uth| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/UTHSA_logo.png
    :target: `UT Health San Antonio`_

.. |hgugm| image:: https://github.com/pymedphys/pymedphys/raw/master/docs/logos/HGUGM_200x200.png
    :target: `Hospital General Universitario Gregorio Marañón`_

.. _`Riverina Cancer Care Centre`: http://www.riverinacancercare.com.au/

.. _`Royal Adelaide Hospital`: http://www.rah.sa.gov.au/

.. _`University of New South Wales`: https://www.unsw.edu.au/

.. _`South Western Sydney Local Health District`: https://www.swslhd.health.nsw.gov.au/

.. _`Anderson Regional Cancer Center`: http://www.andersonregional.org/CancerCenter.aspx

.. _`Northern Beaches Cancer Care`: http://www.northernbeachescancercare.com.au/

.. _`University of Calgary`: http://www.ucalgary.ca/

.. _`Tom Baker Cancer Centre`: https://www.ahs.ca/tbcc

.. _`UT Health San Antonio`: https://www.uthscsa.edu/academics/biomedical-sciences/programs/radiological-sciences-phd

.. _`Hospital General Universitario Gregorio Marañón`: https://www.comunidad.madrid/hospital/gregoriomaranon/

.. END_OF_DOCS_IMPORT

.. _`Tutorials`: https://docs.pymedphys.com/tutes
.. _`How-To guides`: https://docs.pymedphys.com/howto
.. _`Reference`: https://docs.pymedphys.com/ref
.. _`Background`: https://docs.pymedphys.com/background

.. _`library`: https://docs.pymedphys.com/ref/lib
.. _`command line tools`: https://docs.pymedphys.com/ref/cli

.. _`Release Notes`: http://docs.pymedphys.com/release-notes.html
